powered by
AGENCY look-up Table
hy_agency_list(hydat_path = NULL)
The default for this argument is to look for hydat in the same location where it was saved by using download_hydat. Therefore this argument is almost always omitted from a function call. You can see where hydat was downloaded using hy_dir()
download_hydat
hy_dir()
A tibble of agencies
Other HYDAT functions: hy_annual_instant_peaks, hy_annual_stats, hy_daily_flows, hy_daily_levels, hy_daily, hy_data_symbols, hy_data_types, hy_datum_list, hy_monthly_flows, hy_monthly_levels, hy_reg_office_list, hy_sed_daily_loads, hy_sed_daily_suscon, hy_sed_monthly_loads, hy_sed_monthly_suscon, hy_sed_samples_psd, hy_sed_samples, hy_stations, hy_stn_data_coll, hy_stn_data_range, hy_stn_op_schedule, hy_stn_regulation, hy_version
hy_annual_instant_peaks
hy_annual_stats
hy_daily_flows
hy_daily_levels
hy_daily
hy_data_symbols
hy_data_types
hy_datum_list
hy_monthly_flows
hy_monthly_levels
hy_reg_office_list
hy_sed_daily_loads
hy_sed_daily_suscon
hy_sed_monthly_loads
hy_sed_monthly_suscon
hy_sed_samples_psd
hy_sed_samples
hy_stations
hy_stn_data_coll
hy_stn_data_range
hy_stn_op_schedule
hy_stn_regulation
hy_version
# NOT RUN { hy_agency_list() # } # NOT RUN { # }
Run the code above in your browser using DataLab