Learn R Programming

tidyhydat (version 0.3.2)

hy_annual_instant_peaks: Extract annual max/min instantaneous flows and water levels from HYDAT database

Description

Provides wrapper to turn the ANNUAL_INSTANT_PEAKS table in HYDAT into a tidy data frame of instantaneous flows and water levels. station_number and prov_terr_state_loc can both be supplied.

Usage

hy_annual_instant_peaks(station_number = NULL, hydat_path = NULL,
  prov_terr_state_loc = NULL, start_year = "ALL", end_year = "ALL")

Arguments

station_number

A seven digit Water Survey of Canada station number. If this argument is omitted, the value of prov_terr_state_loc is returned.

hydat_path

The default for this argument is to look for hydat in the same location where it was saved by using download_hydat. Therefore this argument is almost always omitted from a function call. You can see where hydat was downloaded using hy_dir()

prov_terr_state_loc

Province, state or territory. If this argument is omitted, the value of station_number is returned. See unique(allstations$prov_terr_state_loc)

start_year

First year of the returned record

end_year

Last year of the returned record

Value

A tibble of hy_annual_instant_peaks

See Also

Other HYDAT functions: hy_agency_list, hy_annual_stats, hy_daily_flows, hy_daily_levels, hy_daily, hy_data_symbols, hy_data_types, hy_datum_list, hy_monthly_flows, hy_monthly_levels, hy_reg_office_list, hy_sed_daily_loads, hy_sed_daily_suscon, hy_sed_monthly_loads, hy_sed_monthly_suscon, hy_sed_samples_psd, hy_sed_samples, hy_stations, hy_stn_data_coll, hy_stn_data_range, hy_stn_op_schedule, hy_stn_regulation, hy_version

Examples

Run this code
# NOT RUN {
## Multiple stations province not specified
hy_annual_instant_peaks(station_number = c("08NM083","08NE102"))

## Multiple province, station number not specified
hy_annual_instant_peaks(prov_terr_state_loc = c("AB","YT"))
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab