Learn R Programming

tidyhydat (version 0.3.2)

hy_annual_stats: Extract annual statistics information from the HYDAT database

Description

Provides wrapper to turn the ANNUAL_STATISTICS table in HYDAT into a tidy data frame of annual statistics. Statistics provided include MEAN, MAX and MIN on an annual basis.

Usage

hy_annual_stats(station_number = NULL, hydat_path = NULL,
  prov_terr_state_loc = NULL, start_year = "ALL", end_year = "ALL")

Arguments

station_number

A seven digit Water Survey of Canada station number. If this argument is omitted, the value of prov_terr_state_loc is returned.

hydat_path

The default for this argument is to look for hydat in the same location where it was saved by using download_hydat. Therefore this argument is almost always omitted from a function call. You can see where hydat was downloaded using hy_dir()

prov_terr_state_loc

Province, state or territory. If this argument is omitted, the value of station_number is returned. See unique(allstations$prov_terr_state_loc)

start_year

First year of the returned record

end_year

Last year of the returned record

Value

A tibble of hy_annual_stats.

Format

A tibble with 8 variables:

STATION_NUMBER

Unique 7 digit Water Survey of Canada station number

Parameter

Parameter being measured. Only possible values are FLOW and LEVEL

Year

Year of record.

Sum_stat

Summary statistic being used.

Value

Value of the measurement. If Parameter equals FLOW the units are m^3/s. If Parameter equals LEVEL the units are metres.

Date

Observation date. Formatted as a Date class. MEAN is a annual summary and therefore has an NA value for Date.

Symbol

Measurement/river conditions

See Also

Other HYDAT functions: hy_agency_list, hy_annual_instant_peaks, hy_daily_flows, hy_daily_levels, hy_daily, hy_data_symbols, hy_data_types, hy_datum_list, hy_monthly_flows, hy_monthly_levels, hy_reg_office_list, hy_sed_daily_loads, hy_sed_daily_suscon, hy_sed_monthly_loads, hy_sed_monthly_suscon, hy_sed_samples_psd, hy_sed_samples, hy_stations, hy_stn_data_coll, hy_stn_data_range, hy_stn_op_schedule, hy_stn_regulation, hy_version

Examples

Run this code
# NOT RUN {
  ## Multiple stations province not specified
  hy_annual_stats(station_number = c("08NM083","05AE027"))
 
  ## Multiple province, station number not specified
  hy_annual_stats(prov_terr_state_loc = c("AB","SK"))
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab