Provides wrapper to turn the DLY_LEVELS table in HYDAT into a tidy data frame. The primary value returned by this
function is discharge. station_number and prov_terr_state_loc can both be supplied. If both are omitted all
values from the hy_stations table are returned. That is a large vector for hy_daily_levels.
hy_daily_levels(station_number = NULL, hydat_path = NULL,
prov_terr_state_loc = NULL, start_date = "ALL", end_date = "ALL",
symbol_output = "code")A seven digit Water Survey of Canada station number. If this argument is omitted, the value of prov_terr_state_loc
is returned.
The default for this argument is to look for hydat in the same location where it
was saved by using download_hydat. Therefore this argument is almost always omitted from a function call.
You can see where hydat was downloaded using hy_dir()
Province, state or territory. If this argument is omitted, the value of station_number
is returned. See unique(allstations$prov_terr_state_loc)
Leave blank if all dates are required. Date format needs to be in YYYY-MM-DD. Date is inclusive.
Leave blank if all dates are required. Date format needs to be in YYYY-MM-DD. Date is inclusive.
Set whether the raw code, or the english or the french translations are outputted. Default
value is code.
A tibble of daily levels
A tibble with 5 variables:
Unique 7 digit Water Survey of Canada station number
Observation date. Formatted as a Date class.
Parameter being measured. Only possible value is Level
Level value. The units are metres.
Measurement/river conditions
Other HYDAT functions: hy_agency_list,
hy_annual_instant_peaks,
hy_annual_stats,
hy_daily_flows, hy_daily,
hy_data_symbols,
hy_data_types, hy_datum_list,
hy_monthly_flows,
hy_monthly_levels,
hy_reg_office_list,
hy_sed_daily_loads,
hy_sed_daily_suscon,
hy_sed_monthly_loads,
hy_sed_monthly_suscon,
hy_sed_samples_psd,
hy_sed_samples, hy_stations,
hy_stn_data_coll,
hy_stn_data_range,
hy_stn_op_schedule,
hy_stn_regulation, hy_version
# NOT RUN {
hy_daily_levels(station_number = c("02JE013","08MF005"),
start_date = "1996-01-01", end_date = "2000-01-01")
hy_daily_levels(prov_terr_state_loc = "PE")
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab