Learn R Programming

tidyhydat (version 0.3.2)

hy_monthly_levels: Extract monthly levels information from the HYDAT database

Description

Tidy data of monthly river or lake levels information from the DLY_LEVELS HYDAT table. station_number and prov_terr_state_loc can both be supplied. If both are omitted all values from the hy_stations table are returned. That is a large vector for hy_monthly_levels.

Usage

hy_monthly_levels(station_number = NULL, hydat_path = NULL,
  prov_terr_state_loc = NULL, start_date = "ALL", end_date = "ALL")

Arguments

station_number

A seven digit Water Survey of Canada station number. If this argument is omitted, the value of prov_terr_state_loc is returned.

hydat_path

The default for this argument is to look for hydat in the same location where it was saved by using download_hydat. Therefore this argument is almost always omitted from a function call. You can see where hydat was downloaded using hy_dir()

prov_terr_state_loc

Province, state or territory. If this argument is omitted, the value of station_number is returned. See unique(allstations$prov_terr_state_loc)

start_date

Leave blank if all dates are required. Date format needs to be in YYYY-MM-DD. Date is inclusive.

end_date

Leave blank if all dates are required. Date format needs to be in YYYY-MM-DD. Date is inclusive.

Value

A tibble of monthly levels.

Format

A tibble with 8 variables:

STATION_NUMBER

Unique 7 digit Water Survey of Canada station number

YEAR

Year of record.

MONTH

Numeric month value

FULL_MONTH

Logical value is there is full record from MONTH

NO_DAYS

Number of days in that month

Sum_stat

Summary statistic being used.

Value

Value of the measurement in metres.

Date_occurred

Observation date. Formatted as a Date class. MEAN is a annual summary and therefore has an NA value for Date.

See Also

Other HYDAT functions: hy_agency_list, hy_annual_instant_peaks, hy_annual_stats, hy_daily_flows, hy_daily_levels, hy_daily, hy_data_symbols, hy_data_types, hy_datum_list, hy_monthly_flows, hy_reg_office_list, hy_sed_daily_loads, hy_sed_daily_suscon, hy_sed_monthly_loads, hy_sed_monthly_suscon, hy_sed_samples_psd, hy_sed_samples, hy_stations, hy_stn_data_coll, hy_stn_data_range, hy_stn_op_schedule, hy_stn_regulation, hy_version

Examples

Run this code
# NOT RUN {
hy_monthly_levels(station_number = c("02JE013","08MF005"), 
  start_date = "1996-01-01", end_date = "2000-01-01")

hy_monthly_levels(prov_terr_state_loc = "PE")
          
# }

Run the code above in your browser using DataLab