Learn R Programming

tidyhydat (version 0.3.2)

hy_reg_office_list: Extract regional office list from HYDAT database

Description

OFFICE look-up Table

Usage

hy_reg_office_list(hydat_path = NULL)

Arguments

hydat_path

The default for this argument is to look for hydat in the same location where it was saved by using download_hydat. Therefore this argument is almost always omitted from a function call. You can see where hydat was downloaded using hy_dir()

Value

A tibble of offices

See Also

Other HYDAT functions: hy_agency_list, hy_annual_instant_peaks, hy_annual_stats, hy_daily_flows, hy_daily_levels, hy_daily, hy_data_symbols, hy_data_types, hy_datum_list, hy_monthly_flows, hy_monthly_levels, hy_sed_daily_loads, hy_sed_daily_suscon, hy_sed_monthly_loads, hy_sed_monthly_suscon, hy_sed_samples_psd, hy_sed_samples, hy_stations, hy_stn_data_coll, hy_stn_data_range, hy_stn_op_schedule, hy_stn_regulation, hy_version

Examples

Run this code
# NOT RUN {
hy_reg_office_list()
# }
# NOT RUN {

# }

Run the code above in your browser using DataLab