Learn R Programming

tidyhydat (version 0.3.2)

hy_sed_samples_psd: Extract instantaneous sediment sample particle size distribution information from the HYDAT database

Description

Provides wrapper to turn the hy_sed_samples_psd table in HYDAT into a tidy data frame of instantaneous sediment sample particle size distribution. station_number and prov_terr_state_loc can both be supplied. If both are omitted all values from the hy_stations table are returned. That is a large vector for hy_sed_samples_psd.

Usage

hy_sed_samples_psd(station_number = NULL, hydat_path = NULL,
  prov_terr_state_loc = NULL, start_date = "ALL", end_date = "ALL")

Arguments

station_number

A seven digit Water Survey of Canada station number. If this argument is omitted, the value of prov_terr_state_loc is returned.

hydat_path

The default for this argument is to look for hydat in the same location where it was saved by using download_hydat. Therefore this argument is almost always omitted from a function call. You can see where hydat was downloaded using hy_dir()

prov_terr_state_loc

Province, state or territory. If this argument is omitted, the value of station_number is returned. See unique(allstations$prov_terr_state_loc)

start_date

Leave blank if all dates are required. Date format needs to be in YYYY-MM-DD. Date is inclusive.

end_date

Leave blank if all dates are required. Date format needs to be in YYYY-MM-DD. Date is inclusive.

Value

A tibble of sediment sample particle size data

Format

A tibble with 5 variables:

STATION_NUMBER

Unique 7 digit Water Survey of Canada station number

SED_DATA_TYPE_EN

Contains the type of sampling method used in collecting sediment for a station

DATE

Contains the time to the nearest minute of when the sample was taken

PARTICLE_SIZE

Particle size (mm)

PERCENT

Contains the percentage values for indicated particle sizes for samples collected

See Also

Other HYDAT functions: hy_agency_list, hy_annual_instant_peaks, hy_annual_stats, hy_daily_flows, hy_daily_levels, hy_daily, hy_data_symbols, hy_data_types, hy_datum_list, hy_monthly_flows, hy_monthly_levels, hy_reg_office_list, hy_sed_daily_loads, hy_sed_daily_suscon, hy_sed_monthly_loads, hy_sed_monthly_suscon, hy_sed_samples, hy_stations, hy_stn_data_coll, hy_stn_data_range, hy_stn_op_schedule, hy_stn_regulation, hy_version

Examples

Run this code
# NOT RUN {
hy_sed_samples_psd(station_number = "01CA004")
          
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab