| hy_stn_data_coll | R Documentation |
hy_stn_data_coll look-up Table
hy_stn_data_coll(
station_number = NULL,
hydat_path = NULL,
prov_terr_state_loc = NULL
)
station_number |
A seven digit Water Survey of Canada station number. If this argument is omitted, the value of |
hydat_path |
The path to the hydat database or NULL to use the default location
used by download_hydat. It is also possible to pass in an existing
database connection from |
prov_terr_state_loc |
Province, state or territory. If this argument is omitted, the value of |
A tibble with 6 variables:
STATION_NUMBER: Unique 7 digit Water Survey of Canada station number
DATA_TYPE: The type of data
Year_from: First year of use
Year_to: Last year of use
MEASUREMENT: The sampling method used in the collection of sediment data or the type of the gauge used in the collection of the hydrometric data
OPERATION: The schedule of station operation for the collection of sediment or hydrometric data
A tibble of hy_stn_data_coll
HYDAT
Other HYDAT functions:
hy_agency_list(),
hy_annual_instant_peaks(),
hy_annual_stats(),
hy_daily(),
hy_daily_flows(),
hy_daily_levels(),
hy_data_symbols,
hy_data_types,
hy_datum_list(),
hy_monthly_flows(),
hy_monthly_levels(),
hy_reg_office_list(),
hy_sed_daily_loads(),
hy_sed_daily_suscon(),
hy_sed_monthly_loads(),
hy_sed_monthly_suscon(),
hy_sed_samples(),
hy_sed_samples_psd(),
hy_stations(),
hy_stn_data_range(),
hy_stn_op_schedule(),
hy_stn_regulation(),
hy_version()
## Not run:
hy_stn_data_coll(station_number = c("02JE013", "08MF005"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.