| hy_stn_datum_conv | R Documentation |
hy_stn_datum_conv look-up Table
hy_stn_datum_conv(
station_number = NULL,
hydat_path = NULL,
prov_terr_state_loc = NULL
)
station_number |
A seven digit Water Survey of Canada station number. If this argument is omitted, the value of |
hydat_path |
The path to the hydat database or NULL to use the default location
used by download_hydat. It is also possible to pass in an existing
database connection from |
prov_terr_state_loc |
Province, state or territory. If this argument is omitted, the value of |
A tibble with 4 variables:
STATION_NUMBER: Unique 7 digit Water Survey of Canada station number
DATUM_FROM: Identifying a datum from which water level is being converted
DATUM_TO: Identifying a datum to which water level is being converted
CONVERSTION_FACTOR: The conversion factor applied to water levels referred to one datum to obtain water levels referred to another datum
A tibble of hy_stn_datum_conv
## Not run:
hy_stn_datum_conv(station_number = c("02JE013", "08MF005"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.