hy_stn_op_schedule look-up Table
hy_stn_op_schedule(station_number = NULL, hydat_path = NULL,
prov_terr_state_loc = NULL)A seven digit Water Survey of Canada station number. If this argument is omitted, the value of prov_terr_state_loc
is returned.
The default for this argument is to look for hydat in the same location where it
was saved by using download_hydat. Therefore this argument is almost always omitted from a function call.
You can see where hydat was downloaded using hy_dir()
Province, state or territory. If this argument is omitted, the value of station_number
is returned. See unique(allstations$prov_terr_state_loc)
A tibble of hy_stn_op_schedule
A tibble with 6 variables:
Unique 7 digit Water Survey of Canada station number
The type of data
Year of operation schedule
First month of use
Last month of use
Other HYDAT functions: hy_agency_list,
hy_annual_instant_peaks,
hy_annual_stats,
hy_daily_flows,
hy_daily_levels, hy_daily,
hy_data_symbols,
hy_data_types, hy_datum_list,
hy_monthly_flows,
hy_monthly_levels,
hy_reg_office_list,
hy_sed_daily_loads,
hy_sed_daily_suscon,
hy_sed_monthly_loads,
hy_sed_monthly_suscon,
hy_sed_samples_psd,
hy_sed_samples, hy_stations,
hy_stn_data_coll,
hy_stn_data_range,
hy_stn_regulation, hy_version
# NOT RUN {
hy_stn_op_schedule(station_number = c("02JE013"))
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab