| plot | R Documentation |
This method plots combined final and provisional data, visually distinguishing between validated (final) and provisional records.
This method plots either daily time series data from HYDAT or realtime data from the datamart. These plots are intended to be convenient and quick methods to visualize hydrometric data.
## S3 method for class 'available'
plot(x = NULL, ...)
## S3 method for class 'hy'
plot(x = NULL, ...)
## S3 method for class 'realtime'
plot(x = NULL, Parameter = c("Flow", "Level"), ...)
x |
Object created by either a hy_daily_* or realtime_dd data retrieval function |
... |
passed to |
Parameter |
Parameter of interest. Either "Flow" or "Level". Defaults to "Flow". |
plot(realtime): plot.realtime
## Not run:
# One station
flows <- available_flows("08MF005")
plot(flows)
## End(Not run)
## Not run:
# One station
fraser <- hy_daily_flows("08MF005")
plot(fraser)
## End(Not run)
## Not run:
# One station
fraser_realtime <- realtime_dd("08MF005")
plot(fraser_realtime)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.