Provides functions to access historical and real-time national 'hydrometric' data from Water Survey of Canada data sources (<http://dd.weather.gc.ca/hydrometric/csv/> and <http://collaboration.cmc.ec.gc.ca/cmc/hydrometrics/www/>) and then applies tidy data principles.
To download the latest version of hydat please:
use the download_hydat() function.
For more information on tidy data please see
Wickham, Hadley. 2014. Tidy Data. The Journal of Statistical Software. 59. https://www.jstatsoft.org/article/view/v059i10
tidy data vignette: https://CRAN.R-project.org/package=tidyr/vignettes/tidy-data.html
For more information on HYDAT
Please see this description of the database: goo.gl/H3NXJQ
This page is landing page for technical description of HYDAT: http://collaboration.cmc.ec.gc.ca/cmc/hydrometrics/www/
This page links to a document that outlines database table definitions: http://collaboration.cmc.ec.gc.ca/cmc/hydrometrics/www/HYDAT_Definition_EN.pdf
Useful links: