A thin wrapper around hy_daily_flows and hy_daily_levels that returns a data frames that
contains both parameters. All arguments are passed directly to these functions.
hy_daily(station_number = NULL, prov_terr_state_loc = NULL, quiet = TRUE,
...)A seven digit Water Survey of Canada station number. If this argument is omitted, the value of prov_terr_state_loc
is returned.
Province, state or territory. If this argument is omitted, the value of station_number
is returned. See unique(allstations$prov_terr_state_loc)
Generate output of parameters successfully queried? Defaults to TRUE. The output can be overly verbose when querying multiple stations but is useful when only querying a few stations.
See hy_daily_flows arguments
A tibble of daily flows and levels
A tibble with 5 variables:
Unique 7 digit Water Survey of Canada station number
Observation date. Formatted as a Date class.
Parameter being measured.
Discharge value. The units are m^3/s.
Measurement/river conditions
Other HYDAT functions: hy_agency_list,
hy_annual_instant_peaks,
hy_annual_stats,
hy_daily_flows,
hy_daily_levels,
hy_data_symbols,
hy_data_types, hy_datum_list,
hy_monthly_flows,
hy_monthly_levels,
hy_reg_office_list,
hy_sed_daily_loads,
hy_sed_daily_suscon,
hy_sed_monthly_loads,
hy_sed_monthly_suscon,
hy_sed_samples_psd,
hy_sed_samples, hy_stations,
hy_stn_data_coll,
hy_stn_data_range,
hy_stn_op_schedule,
hy_stn_regulation, hy_version
# NOT RUN {
hy_daily(station_number = c("02JE013","08MF005"))
# }
Run the code above in your browser using DataLab