hy_reg_office_list: Extract regional office list from HYDAT database
Description
OFFICE look-up Table
Usage
hy_reg_office_list(hydat_path = NULL)
Arguments
hydat_path
The default for this argument is to look for hydat in the same location where it
was saved by using download_hydat. Therefore this argument is almost always omitted from a function call.
You can see where hydat was downloaded using hy_dir()