Provides wrapper to turn the hy_stations table in HYDAT into a tidy data frame of station information. station_number and
prov_terr_state_loc can both be supplied. If both are omitted all values from the hy_stations table are returned. This
is the entry point for most analyses is tidyhydat as establish the stations for consideration is likely the first step in many
instances.
hy_stations(station_number = NULL, hydat_path = NULL,
prov_terr_state_loc = NULL)A seven digit Water Survey of Canada station number. If this argument is omitted, the value of prov_terr_state_loc
is returned.
The default for this argument is to look for hydat in the same location where it
was saved by using download_hydat. Therefore this argument is almost always omitted from a function call.
You can see where hydat was downloaded using hy_dir()
Province, state or territory. If this argument is omitted, the value of station_number
is returned. See unique(allstations$prov_terr_state_loc)
A tibble of stations and associated metadata
A tibble with 15 variables:
Unique 7 digit Water Survey of Canada station number
Official name for station identification
The province, territory or state in which the station is located
The identifier of the regional office responsible for the station. Links to hy_reg_office_list
North-South Coordinates of the gauging station in decimal degrees
East-West Coordinates of the gauging station in decimal degrees
The total surface area that drains to the gauge site (km^2)
The portion of the drainage basin that contributes runoff to the gauge site, calculated by subtracting any noncontributing portion from the gross drainage area (km^2)
Logical. Reference Hydrometric Basin Network station. The Reference Hydrometric Basin Network (RHBN) is a sub-set of the national network that has been identified for use in the detection, monitoring, and assessment of climate change.
Logical. Indicates if a station has the capacity to deliver data in real-time or near real-time
Unique ID of an agency that contributes data to the HYDAT database. The agency is non-WSC and non WSC funded
Unique ID of an agency that operates a hydrometric station
Unique ID for a datum
Other HYDAT functions: hy_agency_list,
hy_annual_instant_peaks,
hy_annual_stats,
hy_daily_flows,
hy_daily_levels, hy_daily,
hy_data_symbols,
hy_data_types, hy_datum_list,
hy_monthly_flows,
hy_monthly_levels,
hy_reg_office_list,
hy_sed_daily_loads,
hy_sed_daily_suscon,
hy_sed_monthly_loads,
hy_sed_monthly_suscon,
hy_sed_samples_psd,
hy_sed_samples,
hy_stn_data_coll,
hy_stn_data_range,
hy_stn_op_schedule,
hy_stn_regulation, hy_version
# NOT RUN {
## Multiple stations province not specified
hy_stations(station_number = c("08NM083","08NE102"))
## Multiple province, station number not specified
hy_stations(prov_terr_state_loc = c("AB","YT"))
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab