A seven digit Water Survey of Canada station number. If this argument is omitted, the value of prov_terr_state_loc
is returned.
hydat_path
The default for this argument is to look for hydat in the same location where it
was saved by using download_hydat. Therefore this argument is almost always omitted from a function call.
You can see where hydat was downloaded using hy_dir()
prov_terr_state_loc
Province, state or territory. If this argument is omitted, the value of station_number
is returned. See unique(allstations$prov_terr_state_loc)
Value
A tibble of hy_stn_datum_conv
Format
A tibble with 4 variables:
STATION_NUMBER
Unique 7 digit Water Survey of Canada station number
DATUM_EN_FROM
Identifying a datum from which water level is being converted
DATUM_EN_TO
Identifying a datum to which water level is being converted
CONVERSTION_FACTOR
The conversion factor applied to water levels referred to
one datum to obtain water levels referred to another datum