Learn R Programming

tidyhydat (version 0.3.2)

hy_stn_remarks: Extract station remarks from HYDAT database

Description

hy_stn_remarks look-up Table

Usage

hy_stn_remarks(station_number = NULL, hydat_path = NULL,
  prov_terr_state_loc = NULL)

Arguments

station_number

A seven digit Water Survey of Canada station number. If this argument is omitted, the value of prov_terr_state_loc is returned.

hydat_path

The default for this argument is to look for hydat in the same location where it was saved by using download_hydat. Therefore this argument is almost always omitted from a function call. You can see where hydat was downloaded using hy_dir()

prov_terr_state_loc

Province, state or territory. If this argument is omitted, the value of station_number is returned. See unique(allstations$prov_terr_state_loc)

Value

A tibble of hy_stn_remarks

Format

A tibble with 4 variables:

STATION_NUMBER

Unique 7 digit Water Survey of Canada station number

REMARK_TYPE_EN

Type of Remark

YEAR

Year of the remark

REMARK_EN

Remark

Examples

Run this code
# NOT RUN {
hy_stn_remarks(station_number = c("02JE013","08MF005"))
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab