| realtime_stations | R Documentation |
An up to date dataframe of all stations in the Realtime Water Survey of Canada hydrometric network operated by Environment and Climate Change Canada
realtime_stations(prov_terr_state_loc = NULL)
prov_terr_state_loc |
Province, state or territory. If this argument is omitted, the value of |
A tibble with 6 variables:
STATION_NUMBER: Unique 7 digit Water Survey of Canada station number
STATION_NAME: Official name for station identification
LATITUDE: North-South Coordinates of the gauging station in decimal degrees
LONGITUDE: East-West Coordinates of the gauging station in decimal degrees
PROV_TERR_STATE_LOC: The province, territory or state in which the station is located
TIMEZONE: Timezone of the station
Other realtime functions:
realtime_dd(),
realtime_ws()
## Not run:
## Available inputs for prov_terr_state_loc argument:
unique(realtime_stations()$prov_terr_state_loc)
realtime_stations(prov_terr_state_loc = "BC")
realtime_stations(prov_terr_state_loc = c("QC", "PE"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.