Learn R Programming

tidyhydat (version 0.3.2)

realtime_stations: Download a tibble of active realtime stations

Description

An up to date dataframe of all stations in the Realtime Water Survey of Canada hydrometric network operated by Environment and Climate Change Canada

Usage

realtime_stations(prov_terr_state_loc = NULL)

Arguments

prov_terr_state_loc

Province/State/Territory or Location. See examples for list of available options. realtime_stations() for all stations.

Format

A tibble with 6 variables:

STATION_NUMBER

Unique 7 digit Water Survey of Canada station number

STATION_NAME

Official name for station identification

LATITUDE

North-South Coordinates of the gauging station in decimal degrees

LONGITUDE

East-West Coordinates of the gauging station in decimal degrees

PROV_TERR_STATE_LOC

The province, territory or state in which the station is located

TIMEZONE

Timezone of the station

See Also

Other realtime functions: realtime_dd

Examples

Run this code
# NOT RUN {
## Available inputs for prov_terr_state_loc argument:
unique(realtime_stations()$prov_terr_state_loc)

realtime_stations(prov_terr_state_loc = "BC")
realtime_stations(prov_terr_state_loc = c("QC","PE"))
# }

Run the code above in your browser using DataLab